"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _toConsumableArray2 = require("babel-runtime/helpers/toConsumableArray");

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _ramda = require("ramda");

var _ramda2 = _interopRequireDefault(_ramda);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getFullRenderedWidth = function getFullRenderedWidth(columnWidths) {
	return columnWidths.length + _ramda2.default.reduce(function (x, _ref) {
		var length = _ref.length;
		return x + length;
	}, 0, columnWidths);
};

var padString = function padString() {
	var string = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";
	var length = arguments[1];
	return string + _ramda2.default.times(_ramda2.default.always(""), length - ("" + string).length + 1).join(" ");
};

var renderRow = function renderRow(_ref2) {
	var renderReadyTasks = _ref2.renderReadyTasks,
	    columnWidths = _ref2.columnWidths;
	return function (row, y) {
		var color = renderReadyTasks[y].color;


		var colors = [].concat((0, _toConsumableArray3.default)(color), [y % 2 ? {
			fn: "bgHex",
			val: "#111"
		} : false]).filter(Boolean);

		return row.map(function (cell, x) {
			return _ramda2.default.reduce(function (string, _ref3) {
				var fn = _ref3.fn,
				    val = _ref3.val;
				return _chalk2.default[fn](val)(string);
			}, padString(cell, columnWidths[x].length) + " ", colors);
		}).join("");
	};
};

var blockTableData = function blockTableData(_ref4) {
	var renderReadyTasks = _ref4.renderReadyTasks,
	    columnWidths = _ref4.columnWidths,
	    tabledData = _ref4.tabledData;
	return [columnWidths.map(function (_ref5) {
		var label = _ref5.label,
		    length = _ref5.length;
		return _chalk2.default.underline(padString(label, length));
	}).join(" ")].concat((0, _toConsumableArray3.default)(tabledData.map(renderRow({
		renderReadyTasks: renderReadyTasks,
		columnWidths: columnWidths,
		tabledData: tabledData
	})))).join("\n");
};

exports.default = function (_ref6) {
	var renderReadyTasks = _ref6.renderReadyTasks,
	    columnWidths = _ref6.columnWidths;

	var tabledData = _ramda2.default.pipe(_ramda2.default.map(function (_ref7) {
		var label = _ref7.label;
		return _ramda2.default.pluck(label, renderReadyTasks);
	}), _ramda2.default.transpose)(columnWidths);

	var blockedTable = blockTableData({
		renderReadyTasks: renderReadyTasks,
		columnWidths: columnWidths,
		tabledData: tabledData
	});

	return blockedTable;
};